pub enum Error {
IoError(Error),
MalformedUtf8(StreamPosition, usize),
}Expand description
Error represents an error from the UTF-8 character reader, either an IO error from the reader or a malformed UTF-8 encoded set of bytes.
Variants
IoError(Error)
An IoError is passed through from the underlying read object.
MalformedUtf8(StreamPosition, usize)
A MalformedUtf8 error occurs when a byte stream contains invalid UTF-8; the position within the stream of the Unicode decoding error is recorded, and the number of bytes that form the invalid UTF-8 encoding (which will be from 1 to 3).
Implementations
Sourceimpl Error
impl Error
Sourcepub fn malformed_utf8<T>(
stream_pos: StreamPosition,
num_bytes: usize,
) -> Result<T>
pub fn malformed_utf8<T>( stream_pos: StreamPosition, num_bytes: usize, ) -> Result<T>
Create an error for a malformed UTF8 decoding within a stream